import React from 'react';
import 'ray';
import '@/i18n';
import {getSystemInfoSync,hideMenuButton, offDeviceOnlineStatusUpdate, onDeviceOnlineStatusUpdate} from '@ray-js/ray'
import { initPanelEnvironment } from '@ray-js/ray';
import _ from 'lodash';

let sbHeight :string = '65rpx';
let is24Hour:boolean = true;
let isOnline:boolean = false;
let weatherData:any[] = [];
let localLanguage:string = 'en';

interface Props {
  children: React.ReactNode;
}

initPanelEnvironment({ useDefaultOffline: true, customTop:'10vh'});

class App extends React.Component<Props> {
  
  componentDidMount() {
    var sysInfo = getSystemInfoSync();
    is24Hour = sysInfo.is24Hour;
    localLanguage = sysInfo.language;
    if(localLanguage.indexOf('zh')>-1){
      localLanguage = 'zh';
    }
    hideMenuButton();
    onDeviceOnlineStatusUpdate(this.onLineListener);
  }

  componentWillUnmount(): void {
    offDeviceOnlineStatusUpdate(this.onLineListener);
  }

  render() {
    return this.props.children;
  }

  readStatusBarHeight():string{
    return sbHeight;
  }

  onLineListener(res:ty.device.Online){ 
    isOnline = res.online;  
  }

  is24Hour():boolean{
    return is24Hour;
  }

  readLocalLanguage():string{
    return localLanguage;
  }

  isDeviceOnLine():boolean{
    return isOnline;
  }

  setDeviceOnLine(isOn:boolean){
    isOnline = isOn;
  }

  //读取天气数据
  readWeatherData(){
    return weatherData;
  }

  //设置天气数据
  setWeatherData(data:any[]){
    weatherData = data;
  }
}

export default App;
