import React,{useState } from 'react';
import {Icon,Text, View } from '@ray-js/components';
import styles from './index.module.less';
import styles_var from '../../../variables.less';

interface RadioBottomDialogProps {
    /**
     * 弹窗标题
     */
    title:string;
    /**
     * 弹窗内部数据
     */
    data: Array<ItemData>;
    /**
     * 数据回调
     * @param param0 
     * @returns 
     */
    dataCallback?: (callback:CallBackData)=>void;
}

interface ItemData{
    /**
     * 该项是否被选中
     */
    checked:boolean;
    /**
     * item项显示文本
     */
    txt:string;
    /**
     * item项数值
     */
    value:number;
}


interface CallBackData{
    /**
     * 回调出去的数据
     */
    callback:ItemData;
    /**
     * 弹窗选择（true 确认；false 取消）
     */
    complete:boolean;
}

/**
 * 
 * 低部弹出双向选择的单选窗 
 */
export const RadioBottomDialog: React.FC<RadioBottomDialogProps> = ({title, data, dataCallback}) =>{
    const [itemDatas,setItemDatas] = useState(data);
    const [curItemData,setCurItemData] = useState(null)

    function selectItem(item:ItemData){      
        if(!item?.checked){
            for (let index = 0; index < data.length; index++) {
                const element = data[index];
                if(item.value===element.value){
                    element.checked = true; 
                    setCurItemData(element)                
                }else{
                    element.checked = false;
                }
                itemDatas[index] = element;
            }
            setItemDatas(itemDatas);
        }else{
            setCurItemData(item); 
        }
    }

    return(
        <View className={styles.container}>
            <Text className={styles.title} selectable={false}>{title}</Text>
            {
                itemDatas?.map(item=>{
                    return(
                        <View className={styles.item} key={item.value}>
                            <View className={styles_var.divider_0}></View>
                            <View className={styles.item_content} onClick={()=>{selectItem(item)}}>
                                <View className={styles.item_content_1}>
                                    <Text className={styles.item_content_txt}>{item.txt}</Text>
                                </View>
                                <View style={{display:item.checked?'flex':'none'}} className={styles.item_content_2}>
                                    <Icon type='icon-checkmark' size={20} color='#ff00ff' style={{marginRight:'20rpx'}}></Icon>
                                </View>
                            </View>
                        </View>
                    )
                })
            }
            <View className={styles.btn_container}>
                <Text className={styles.btn_cancel} onClick={()=>{
                    dataCallback({complete:false,callback:curItemData})
                }}>取消</Text>
                <View className={styles.divider_v}></View>
                <Text className={styles.btn_comfirm} onClick={()=>{
                    dataCallback({complete:true,callback:curItemData})
                }}>确认</Text>
            </View>
        </View>
    );
}