import Chart from '@ray-js/chart';
import React, { useState,useEffect } from 'react';
import _ from 'lodash';

export interface LineChartProps{
  lineData?:Array<LineData>
}

interface LineData{
  time: string,
  type:string,
  tem?:number 
}

export const LineChart:React.FC<LineChartProps>=({lineData})=>{
  const [dates, setDates] = useState([]);
  useEffect(() => {
    setDates(lineData);
  }, []);

  // 为了防止图表重复渲染，必须使用 React.useCallback 包裹一下回调函数
  const onTooltipShow = event => {
    console.log('onTooltipShow', event);
  };

  const onTooltipHide = React.useCallback(event => {
    console.log('onTooltipHide', event);
  }, []);  

  const onTooltipChange = event => {
    console.log('onTooltipChange', event);
  };
  
  return(
    <Chart 
      data={dates}
      onTooltipShow={onTooltipShow}
      onTooltipHide={onTooltipHide}
      onTooltipChange={onTooltipChange}
      onInit={`
        chart.axis(true);
        chart.tooltip({
          custom:true,
          showCrosshairs: true,
          showItemMarker: false,
          layout: 'vertical',
          crosshairsStyle: {
            stroke: 'rgba(0, 0, 0, 0.25)',
            lineWidth: 2
          },
          onChange: function(obj) {
            var legend = chart.get('legendController').legends.top[0];
            var tooltipItems = obj.items;   
            callMethod('onTooltipChange', tooltipItems);        
            var legendItems = legend.items;
            var map = {};
            legendItems.forEach(function(item){
              map[item.name] = _.clone(item);
            });
            tooltipItems.forEach(function(item){            
              var name = item.name;
              var value = item.value;
              // console.log('item:',item.origin);
              if (map[name]) {
                map[name].value = value;
              }
            });
            legend.setItems(_.values(map));
          },
          onHide:function onHide() {
            callMethod('TooltipHide');
            var legend = chart.get('legendController').legends.top[0];
            legend.setItems(chart.getLegendItems().type);
          },
          onShow: function onShow(obj){
            //obj: { x, y, title, items }
            var items = obj.items;
            callMethod('TooltipShow', items);
            var newitems = [];
            // console.log('items:',items[0].name,items[0].value,items[1].name,items[1].value);
            if(items[0].name!=='ACME'){
              items[0].name = 'ACME';
              items[0].value = null;
            }else{
              if(items[1].name!=='Compitor'){
                items[1].name = 'Compitor';
                items[1].value = null;
              }
            }
            newitems.push(items[0]);
            newitems.push(items[1]);
          }
        });
        chart.legend({
          clickable:false,
          align:'center',
          marker: function marker(x, y, r, ctx) {
            // 11px * 9px
            ctx.save();
            ctx.lineWidth = 2;
            ctx.strokeStyle = ctx.fillStyle;
            ctx.moveTo(x - 5.5, y - 4);
            ctx.lineTo(x + 5.5, y - 4);
            ctx.stroke();
            ctx.restore();
            ctx.globalAlpha = 0.1;
            ctx.moveTo(x - 5.5, y - 4);
            ctx.lineTo(x + 5.5, y - 4);
            ctx.lineTo(x + 5.5, y + 4);
            ctx.lineTo(x - 5.5, y + 4);
            ctx.closePath();
          }
        });
        data.forEach(function(obj){
          chart.guide().point({
            position: [ obj.time, obj.value ],
            style: {
              fill: '#1890ff',
              r: 3
            }
          });  
          chart.guide().text({
            position: [ obj.time, obj.value ],
            content: obj.value,
            style: {
              fill: '#1890ff',
              textAlign: 'center'
            },
            offsetY: -10
          });
        });
        chart.area().position('time*value').color('type',['l(90) 0:#1677FF 1:transparent','l(90) 0:#00B7F4 1:transparent']).shape('smooth');
        chart.line().position('time*value').color('type',['#1677FF','#00B7F4']).shape('smooth');
        chart.point().position('time*value').shape('smooth').style({
          stroke: '#fff',
          lineWidth: 1
        });
        chart.animate({
          line: {
            appear: true
          }
        });
        chart.render();
      `}
    />
  );
}