import {View} from '@ray-js/components';
import {Button,  exitMiniProgram, Icon,Text,Image, onDpDataChange, offDpDataChange, PickerView, PickerViewColumn, showLoading, publishDps, hideLoading, getWeatherQuality, Slider} from '@ray-js/ray';
import { hooks, utils} from '@ray-js/panel-sdk';
import React, {useEffect, useState } from 'react';
import styles from './index.module.less';
import Charts from '@ray-js/stat-charts';
import SjsSlider, { SjsSliderEventData } from '@ray-js/components-ty-slider/lib/slider';
import _ from 'lodash';
import App from '@/app';
import Tabbar from '@ray-js/components-ty-tabbar';
import Strings from '@/i18n';
import MyChart from '@ray-js/chart';
import Battery from '@ray-js/battery';
import { TempUnit,getDpStateMapByDevInfo,readCurDate0, showFailedDialog } from '@/utils';
import { LineChart } from '@/components/lineChart';
const { useDevInfo } = hooks;
const statusBarHeight:string = App.prototype.readStatusBarHeight();
const localData:any = {deviceID:null,deviceName:'',produceID:null,lower:0,upper:1345,tempUnit:'c'};

export function Home() {
  const [curPage,setCurPage] = useState(0);
  const [deviceName,setDeviceName] = useState('');
  const devInfo = useDevInfo();
  const [limitTemp,setLimitTemp] = useState({title:'',lower:-1,upper:499,max:899,min:0,tempTip:Strings.getLang('desc_temptip_setting'),maxTitle:Strings.getLang('desc_max_temp_setting'),minTitle:Strings.getLang('desc_min_temp_setting')});
  const [myChartData,setMyChartData] = useState([{time:'00',type: "ACME",value:10},{time:'00',type: "Compitor",value:18},
  {time:'01',type: "ACME",value:9},{time:'01',type: "Compitor",value:20},
  {time:'02',type: "ACME",value:15},{time:'02',type: "Compitor",value:26},
  {time:'03',type: "ACME"},{time:'03',type: "Compitor",value:24},
  {time:'04',type: "ACME",value:10},{time:'04',type: "Compitor",value:20},
  {time:'05',type: "ACME",value:14},{time:'05',type: "Compitor",value:30}]);
  // const [tableTitle,setTableTitle] = useState({title:'',rang:[Strings.getLang('desc_temp'),Strings.getLang('desc_hum')]});
  const [tableData,setTableData] = useState({devIdList:[],dpList:[],startDate:'',endDate:'',unit:[Strings.getLang('des_unit_c'),Strings.getLang('des_unit_hum')]});

  useEffect(()=>{
    localData.deviceID = null;
    onDpDataChange(dpDataChange);
  },[]);

  useEffect(()=>{
    // console.log('devInfo:',devInfo);
    if(devInfo&&localData.deviceID===null){
      localData.deviceName = devInfo.name;
      localData.deviceID = devInfo.devId;
      localData.produceID = devInfo.productId;
      setDeviceName(devInfo.name);
      const data = getDpStateMapByDevInfo(devInfo);
      if(data){
        localData.tempUnit = data.temp_unit_convert;
        setTable(localData.tempUnit);
        // setMyChartData([{time:'00',tem:20},{time:'01',tem:18},{time:'02',tem:9},{time:'03',tem:19},{time:'04',tem:15},{time:'05',tem:26},{time:'06',tem:10}]);
        // getWeatherQuality({devId:localData.deviceID,isLocal:false}).then((res)=>{
        //   let curWeatherData = res.w;     
        //   console.log('天气质量:',curWeatherData);
        // })
      }
    }
  },[devInfo]);

  useEffect(()=>{return()=>{
    offDpDataChange(dpDataChange);
  }},[])

  useEffect(()=>{
    if(curPage===1){
      setLimitTemp({
        title: "温度报警",
        lower: 368,
        upper: 744,
        max: 899,
        min: 0,
        tempTip: "温度报警数值设置范围为-19.9~70.0℃",
        maxTitle: "上限值(℃):",
        minTitle: "下限值(℃):"
    })
    }
  },[curPage])

  const setTable = (unit:string)=>{
    const dataDate = readCurDate0();
    let dpListData = [{id:'1',name:'温度'},{id:'2',name:'湿度'}];
    let showUnit = null;
    if(unit===TempUnit.C){
      showUnit = [Strings.getLang('des_unit_c'),Strings.getLang('des_unit_hum')];
    }else{
      showUnit = [Strings.getLang('des_unit_f'),Strings.getLang('des_unit_hum')];
    }
    const tableData = {devIdList:[localData.deviceID],dpList:dpListData,startDate:dataDate,endDate:dataDate,unit:showUnit};
    setTableData(tableData);
  }

  //跳转到其他界面 0侧滑菜单栏 1 天气详情界面 5 闹钟界面 6 侧滑
  function navigateToAct(type: string){
    // ty.router({url:'thing_add_smart',fail(params) {
    //   console.log('界面跳转fail:',params)
    // },});
    if(localData.tempUnit!==type){     
      showLoading({title:'',mask:true});
      publishDps({deviceId:localData.deviceID,dps:{9:type},mode: 2, options: {}, pipelines: [],success(res) {
        if(res){
          localData.tempUnit = type;
          setTable(type);
          hideLoading();
        }else{
          hideLoading();
          showFailedDialog();
        }
      },fail(e) {
        hideLoading();
        showFailedDialog();
      }});
    }
  }


  const dpDataChange = (res:any)=>{
    const dpData = res.dps;
    if(dpData!==null&&dpData!==undefined){
      _.mapKeys(dpData,(data,dpID)=>{
        switch(dpID){
          case '9':
            if(typeof data === 'string'&&localData.tempUnit!==data){
              localData.tempUnit = data;
              if(curPage===0){
                setTable(data);
              }
            }
            break;
        }
      });
    }
  }

  // const setTableTitleData = (unit:string)=>{
  //   const curDate = readCurDate();
  //   let curTableTitle = null;
  //   let sTitle1 = null;
  //   if(unit===TempUnit.C){
  //     sTitle1 = Strings.getLang('desc_temp').concat('(℃)');       
  //   }else{
  //     sTitle1 = Strings.getLang('desc_temp').concat('(℉)');
  //   }      
  //   const sTitle2 = Strings.getLang('desc_hum').concat('(%RH)');
  //   curTableTitle = {title:curDate,rang:[sTitle1,sTitle2]};
  //   setTableTitle(curTableTitle);  
  // }

  const dealBrightness= (event:any,type:boolean)=>{
    localData.sliderStatus = type;
    // const brivalue = parseBgBrightness(1,event.value);
    console.log('手动调节背光sliderStatus:',type);
    // if(localSetting.bgBri!==brivalue){  
    //   localSetting.bgBri = brivalue;
    //   publishDps({deviceId:deviceData.deviceId,dps:{104:brivalue},mode: 2, options: {}, pipelines: [],success(res) {
    //   },fail(e) {
    //   }});
    // }
  }

  return (
    <View className={styles.body_home}>
      <View style={{display:'flex',flexDirection:'column',width:'100%',height:'100%',paddingTop:statusBarHeight}}>
        <View className={styles.bg_title_home}>
          <View onClick={()=>{exitMiniProgram()}}>
            <Icon type='icon-left' color='#70706f' size={24}></Icon>
          </View>
          <Text style={styles.txt_title_home}>{deviceName}</Text>
          <Image src={require('@/res/images/more.png')} style={{width:'48rpx',height:'48rpx'}}></Image>
        </View>
        <View style={{display:curPage===0?'flex':'none',flexDirection:'column',flexGrow:'1',alignItems:'center'}}>       
          <Button onClick={()=>{navigateToAct(TempUnit.C)}}>切换摄氏度（℃）</Button> 
          <Button onClick={()=>{navigateToAct(TempUnit.F)}}>切换华氏度（℉）</Button> 
          {/* <View style={{display:'flex',flexDirection:'row'}}>
            <Charts style={{padding:'0',margin:'0'}} range='15min' type='avg' startDate={tableData.startDate} endDate={tableData.endDate} devIdList={tableData.devIdList} dpList={tableData.dpList} unit={tableData.unit} chartType='line-area' colors={['#f7bc46','#f98639']} placeholder={{loading: Strings.getLang('desc_loading_table'), error: Strings.getLang('desc_error_table'), none: Strings.getLang('desc_nodata_table')}} dataTransformer={data=>data.map(item=>({
                  ...item,data:item.data.map(i=>({
                    ...i,value:!i.value||1?i.value:`${utils.c2f(+i.value)}`,
                  }))
                }))}/>
          </View>    */}
          <Battery type='horizontal' value={100} /> 
          <SjsSlider instanceId='tempID' startMin={limitTemp.min} startMax={limitTemp.max} start={limitTemp.lower} endMin={limitTemp.min} endMax={limitTemp.max} end={limitTemp.upper} step={1} max={limitTemp.max} mode='range' barStyle={{backgroundColor:'#f7bc46'}} barPad={-5}/>
          <LineChart lineData={myChartData}></LineChart>
          <View style={{display:'flex',flexDirection:'row',flexGrow:'1'}}>
            <Slider style={{width:'200px'}} activeColor='#f7bc46' step={1} min={0} max={3} blockSize={24} value={2} onChanging={(e)=>{dealBrightness(e,true)}} onChange={(e)=>{dealBrightness(e,false)}}/>
          </View>  
        </View>
        <View style={{display:curPage===1?'flex':'none',flexDirection:'column',flexGrow:'1',margin:'0 20rpx',alignItems:'center'}}>
          <Button onClick={()=>{navigateToAct('0')}}>进入历史界面</Button>
          <SjsSlider instanceId='testID' startMin={limitTemp.min} startMax={limitTemp.max} start={limitTemp.lower} endMin={limitTemp.min} endMax={limitTemp.max} end={limitTemp.upper} step={1} max={limitTemp.max} mode='range' barStyle={{backgroundColor:'#f7bc46'}} barPad={-5}/>
        </View>
        <Tabbar onChange={(value)=>{
          setCurPage(value);
        }}>
          <Tabbar.TabItem icon={<Icon type='icon-alarm' size={30}/>} activeIcon={<Icon type='icon-alarm' color='#f8db63' size={30}/>}>闹钟</Tabbar.TabItem>
          <Tabbar.TabItem icon={<Icon type="icon-a-wrenchandscrewdriverfill" size={30}/>} activeIcon={<Icon type='icon-a-wrenchandscrewdriverfill' color='#f8db63' size={30}/>}>设置</Tabbar.TabItem>
        </Tabbar>
      </View>
    </View>
  );
}

export default Home;

