/* eslint-disable no-bitwise */
/**
 * 可以考虑 JS API 暴露
 */
import _ from 'lodash';
import { DevInfo, utils } from '@ray-js/panel-sdk';
import Strings from '@/i18n';
import { showToast } from '@ray-js/ray';

export const getDpIdMapByDevInfo = (
  devInfo: DevInfo
): Record<string, DevInfo['schema'][number]> => {
  const dpIdMap = _.mapKeys(devInfo.schema, schemaInfo => schemaInfo.id);
  return dpIdMap;
};

export const mapDpsMapToDpStateMap = (dpsMap: Record<string, any>, devInfo: DevInfo) => {
  const dpIdMap = getDpIdMapByDevInfo(devInfo);
  const dpStateMap = _.mapKeys(dpsMap, (__, dpId) => dpsMap[dpId]);
  return dpStateMap;
};

/**
 *
 * @param devInfo
 * @returns dpState 对象
 * ```
 * {
 *   switch: true,
 *   ...
 * }
 * ```
 */
export const getDpStateMapByDevInfo = (devInfo: DevInfo): Record<string, any> => {
  const { dps, schema } = devInfo;
  const dpStateMap = {};
  _.forEach(schema, schemaInfo => {
    dpStateMap[schemaInfo.code] = dps[schemaInfo.id];
  });
  return dpStateMap;
};

export function parseNumToArr(label: string[], num: number) {
  const arr = [];
  label.forEach((item, index) => {
    const c = 1 << index;
    if ((c & num) !== 0) {
      arr.push(`${index + 1}`);
    }
  });
  return arr;
}

/**
 * 将背光亮度枚举类型转换为对应的number类型
 * @param light 背光亮度枚举类型
 * @returns number类型值
 */
export function parseBgLight(light:string){
  let bgLight = 0;
  switch(light){
    case 'low':
      bgLight = 1;
      break;  
    case 'middle':
      bgLight = 2;
      break;  
    case 'high':
      bgLight = 3;
      break;  
      default:
        break;
  }
  return bgLight;
}

/**
 * 涂鸦电池组件电量状态值范围 [0,9]低 [10,19]中 [20,100]高
 * @param power 电量状态
 * @returns 电量值
 */
export function parseBattery(power:string){
  let battery = 100;
  switch(power){
    case 'low':
      battery = 9;
      break;  
    case 'middle':
      battery = 19;
      break;
    case 'high':
      battery = 99;
      break
      default:
        break;
  }
  return battery;
}

/**
 * 读取当前以yyyy-MM-dd形式展示的日期
 * @returns yyyy-MM-dd形式的日期字符串
 */
export function readCurDate(){
  return utils.dateFormat('yyyy-MM-dd',new Date());
}

/**
 * 读取当前以yyyyMMdd形式展示的日期
 * @returns yyyyMMdd形式的日期字符串
 */
export function readCurDate0(){
  return utils.dateFormat('yyyyMMdd',new Date());
}

/**
 * 当前指定格式的年月
 * @returns yyyyMM
 */
export function readCurMonth(){
  return utils.dateFormat('yyyyMM',new Date());
}

export function readFirstDateByCurMonth(){
  var str = utils.dateFormat('yyyyMM',new Date());
  return str.concat('01');
}

export function readFirstMonthByCurYear(){
  var str = utils.dateFormat('yyyy',new Date());
  return str.concat('01');
}

/**
 * 功能点当前要获取数据的开始截止日期
 * @param date 读取指定日期(如20230524 202305 2023)
 * @param handleType 对指定日期进行的操作 0 上一；1下一
 * @param dateType 对指定日期进行操作的时间类型  1（天）、2（小时）、4（月）
 * @param startDate 起始日期 yyyyMMdd/yyyyMM
 * @param endDate 截止日期 yyyyMMdd/yyyyMM
 * @returns 返回指定日期
 */
export function readDpDataStartDeadline(date:string,dateType:number,startDate:string,endDate:string,handleType?:number){
  //curDate 20230524
  // var curDate = readCurDate0();
  //初始化返回数据
  var speDate = {start:null,end:null}
  var reg =/(\d{4})\-(\d{2})\-(\d{2})/;   
  startDate = startDate.replace(reg,'$1$2$3');
  endDate = endDate.replace(reg,'$1$2$3');
  console.log('startDate:',startDate,'endDate:',endDate);
  switch(dateType){
    case 1:
      reg =/(\d{4})\-(\d{2})/;   
      date = date.replace(reg,'$1$2');     
      date = date.concat('01');
      // console.log('date:',date);
      var newDate = new Date(parseInt(date?.substring(0,4)),parseInt(date.substring(4,6))-1,1);
      if(handleType!==undefined){
        // var newMiSecond = utils.dateToTimer(date)*1000;
        // var newDate = new Date(newMiSecond);
        var newCurDate = endDate.substring(0,6);
        if(handleType===1){
          if(newCurDate>date){
            const firstDate = new Date(newDate.getFullYear(), newDate.getMonth() + 1, 1);
            speDate.start = utils.dateFormat('yyyyMMdd',firstDate);
            var day = new Date(firstDate.getFullYear(), firstDate.getMonth()+1, 0).getDate();
            const enddate = new Date(newDate.getFullYear(), newDate.getMonth()+1, day);
            date = utils.dateFormat('yyyyMMdd',enddate);
            if(endDate>date){
              speDate.end = date;
            }else{
              speDate.end = endDate;
            }
          }  
        }else{
          const firstDate = new Date(newDate.getFullYear(), newDate.getMonth() - 1, 1);
          const firstDateStr = utils.dateFormat('yyyyMMdd',firstDate);
          if(firstDateStr<startDate){
            speDate.start = startDate;
          }else{
            speDate.start = firstDateStr;
          }
          var day = new Date(newDate.getFullYear(), newDate.getMonth(), 0).getDate();
          const enddate = new Date(newDate.getFullYear(), newDate.getMonth() - 1, day);
          speDate.end = utils.dateFormat('yyyyMMdd',enddate);
        } 
      }else{
        var lastDate = new Date(newDate.getFullYear(),newDate.getMonth()+1,0);
        speDate.end = utils.dateFormat('yyyyMMdd',lastDate);
        if(date>=startDate){
          speDate.start = date;
          if(speDate.end>endDate){
            speDate.end = endDate;
          }
        }else{
          speDate.start = startDate;
          if(speDate.end>endDate){
            speDate.end = endDate;
          }
        }
      }
      break;
    case 2:
      date = date.replace(reg,'$1$2$3');
      if(handleType!==undefined){
        // var newMiSecond = utils.dateToTimer(date)*1000;
        // var newDate = new Date(newMiSecond);
        var newDate = new Date(parseInt(date?.substring(0,4)),parseInt(date?.substring(4,6))-1,parseInt(date?.substring(6,8)));
        if(handleType===1){
          if(endDate>date){
            newDate.setDate(newDate.getDate()+1);
            date = utils.dateFormat('yyyyMMdd',newDate);
            speDate.start = date;
            speDate.end  = date;
          }       
        }else{
          if(date>startDate){
            newDate.setDate(newDate.getDate()-1);
            date = utils.dateFormat('yyyyMMdd',newDate);
            speDate.start = date;
            speDate.end  = date;
          }
        }
      }else{
        speDate.start = date;
        speDate.end  = date;
      }
      break;
    case 4:       
      if(handleType!==undefined){ 
        date = date.concat('0101');
        // var newMiSecond = utils.dateToTimer(date)*1000;
        // var newDate = new Date(newMiSecond); 
        var newDate = new Date(parseInt(date?.substring(0,4)),0,1);
        if(handleType===1){
          var newCurDate = endDate.substring(0,4);
          if(newCurDate>date){
            var newYear = (newDate.getFullYear()+1)+'';
            speDate.start = newYear.concat('01');
            if(newYear===newCurDate){
              speDate.end = endDate.substring(0,6);
            }else{
              speDate.end = newYear.concat('12');
            }
          }
        }else{
          var startYear = startDate?.substring(0,4);
          var newYear = (newDate.getFullYear()-1)+'';
          if(newYear>=startYear){
            if(newYear===startYear){
              speDate.start = startDate?.substring(0,6);
            }else{
              speDate.start = newYear.concat('01');
            }
            speDate.end = newYear.concat('12');
          }
        }
      }else{
        //date 2023
        var curYear = endDate.substring(0,4);
        var startYear = startDate.substring(0,4);
        if(date>startYear){
          speDate.start = date.concat('01');
          if(date<curYear){
            speDate.end = date.concat('12');
          }else{
            speDate.end = endDate.substring(0,6);
          }
        }else{
          speDate.start = startDate.substring(0,6);
          if(date<curYear){
            speDate.end = date.concat('12');
          }else{
            speDate.end = endDate.substring(0,6);
          }
        }
      }
      break;
      default:
        break;    
  }
  return speDate;
}

/**
 * 转换日期格式 yyyyMMdd->yyyy-MM-dd
 * @param date 
 */
export function changeDateFormater(date:string){
  var year = date.substring(0,4);
  var month = date.substring(4,6);
  var day = date.substring(6,8);
  return year.concat('-').concat(month).concat('-').concat(day);
}

export function readCurWeek(){
  return new Date().getDay();
}

/**
 * 
 * @param weather 第一天的日期 yyyy-MM-dd
 * @returns 返回当前7天天气的对应星期文本
 */
export function readWeeks(weather:any){
  var weeks = new Array(7);
  for (let index = 0; index < 7; index++) {      
    weeks[index] = Strings.getLang('week_'+index);
  }
  if(weather!==null){
    const curDate = readCurDate();
    let startIndex = 0;
    for (let index = 0; index < weather.length; index++) {
      const element = new Date(weather[index].sunRiseTimeStamp);
      const date = utils.dateFormat('yyyy-MM-dd',element);
      if(curDate===date){
        startIndex = index;
        break;
      }
    }
    weeks[startIndex] = Strings.getLang('week_7'); 
  }else{
    var curWeek = readCurWeek();
    weeks[curWeek] = Strings.getLang('week_7');    
  }
  return weeks;
}

export function parseWeatherData(weather:any,isTempC:boolean){
  const length = weather.length;
  let weatherDatas = [length];
  var weeks = new Array(7);
  for (let index = 0; index < 7; index++) {      
    weeks[index] = Strings.getLang('week_'+index);
  }
  const curDate = readCurDate();
  for (let index = 0; index < length; index++) {
    var curWeather = weather[index];
    var sunRise = (curWeather.sunrise).split(' ');
    var sunset = (curWeather.sunset).split(' ');
    const date = sunRise[0];
    var newDate = new Date(date);
    var curWeek = newDate.getDay();
    var strDate = utils.dateFormat('MM/dd',newDate);
    if(curDate===date){
      weeks[curWeek] = Strings.getLang('week_7'); 
    }
    var codeIndex = parseWeatherCode(curWeather.conditionNum);
    var presssureValue = curWeather.pressure;
    if(presssureValue===undefined){
      presssureValue = '--';
    }
    var tempValue = curWeather.temp;
    if(tempValue===undefined||tempValue===null){
      tempValue = '--';
    }else{
      if(!isTempC){
        tempValue = Math.floor(320+1.8*tempValue);
        tempValue = utils.scaleNumber(1,tempValue);
      }
    }
    var hTempValue = curWeather.thigh;
    var lTempValue = curWeather.tlow;
    if(!isTempC){
      hTempValue = Math.floor(32+1.8*hTempValue);
      lTempValue = Math.floor(32+1.8*lTempValue);
    }
    weatherDatas[index] = {
      date: strDate,
      week: weeks[curWeek],
      iconUrl: curWeather.condIconUrl,
      iconIndex:codeIndex[0],
      bgIcon:codeIndex[1],
      itemIcon:codeIndex[2],
      weatherCode: curWeather.conditionNum,
      weatherTxt: curWeather.condition,
      humidity: curWeather.humidity,
      pressure: presssureValue,
      sunRise: sunRise[1],
      sunSet: sunset[1],
      temp: tempValue,
      thigh: hTempValue,
      tlow: lTempValue,
      uvi: curWeather.uvi,
      windDir: curWeather.windDir,
      windSpeed: curWeather.windSpeed
    }
  }
  return weatherDatas;
}

/**
 * 天气状态对应图序号 
 * 0 未知  1晴(3) 2多云(2) 3阴(1) 4雷电(2) 5雷阵雨(2) 6小雨(3) 7中雨(5)
 * 8大雨(3) 9暴雨(3) 10雨夹雪(2)  11小雪(4) 12中雪(3) 13大雪(1) 14暴雪(5) 15冰雹(2)
 * 16尘卷风(1) 17扬沙(1) 18沙尘暴(2) 19浮尘(1) 20雾(3)
 * @param code 
 */
export function parseWeatherCode(code:string){
  var imgIndex:number[] = [0,0,0];
  switch(code){
    case '119':
    case '120':
    case '146':
      imgIndex[0] = 1;
      break;
    case '129':
    case '142':
      imgIndex[0] = 2;
      imgIndex[1] = 1;
      imgIndex[2] = 1;
      break;
    case '132':
      imgIndex[0] = 3;
      imgIndex[1] = 1;
      imgIndex[2] = 2;
      break;  
    case '102':
    case '110':
      imgIndex[0] = 4;
      imgIndex[1] = 2;
      imgIndex[2] = 3;
      break;
    case '136':
    case '143':
      imgIndex[0] = 5;
      imgIndex[1] = 2;
      imgIndex[2] = 4;
      break;
    case '111': 
    case '118':
    case '139':  
      imgIndex[0] = 6;
      imgIndex[1] = 2;
      imgIndex[2] = 4;
      break;
    case '108':
    case '112':
    case '122':      
    case '141':
    case '144':        
      imgIndex[0] = 7;
      imgIndex[1] = 2;
      imgIndex[2] = 4;
      break;           
    case '101':
    case '123': 
    case '145': 
      imgIndex[0] = 8;
      imgIndex[1] = 2;
      imgIndex[2] = 4;
      break;             
    case '107':
    case '125':
    case '134':
      imgIndex[0] = 9;
      imgIndex[1] = 2;
      imgIndex[2] = 4;
      break; 
    case '113': 
    case '128':
    case '137':
      imgIndex[0] = 10;  
      imgIndex[1] = 3;
      imgIndex[2] = 5;
      break;  
    case '104': 
    case '130':
    case '133':
      imgIndex[0] = 11;  
      imgIndex[1] = 3;
      imgIndex[2] = 5;
      break; 
    case '105':
    case '131':
    case '138':  
      imgIndex[0] = 12;
      imgIndex[1] = 3;
      imgIndex[2] = 5;
      break;
    case '124': 
      imgIndex[0] = 13;
      break; 
    case '126':
      imgIndex[0] = 14;
      imgIndex[1] = 3;
      imgIndex[2] = 5;
      break;  
    case '115':  
    case '127':               
      imgIndex[0] = 15;
      imgIndex[1] = 3;
      imgIndex[2] = 6;
      break;
    case '114':
      imgIndex[0] = 16;
      imgIndex[1] = 4;
      imgIndex[2] = 7;
      break;
    case '117':
      imgIndex[0] = 17;
      imgIndex[1] = 4;
      imgIndex[2] = 8;
      break;
    case '103':
    case '116':
      imgIndex[0] = 18;
      imgIndex[1] = 4;
      break;
    case '109':
      imgIndex[0] = 19;
      imgIndex[1] = 4;
      imgIndex[2] = 9;
      break;
    case '106':
    case '121':
    case '140':
      imgIndex[0] = 20;
      imgIndex[1] = 1;
      imgIndex[2] = 2;
      break;
      default:
        break;                                                 
  }
  return imgIndex;
}

export function parseClockLoopTxt(loop:number){
  var loopTxt = '';
  if(loop===0){
    loopTxt = Strings.getLang('weeks_0');
  }else if(loop===1){
    loopTxt = Strings.getLang('week_8');
  }else{
    var weeks = new Array(7);
    for (let index = 0; index < 7; index++) {      
      weeks[index] = Strings.getLang('week_'+index);
    }
    for (let index = 0; index < 7; index++) {
      const value = utils.getBitValue(loop,index);
      if(value!==0){
        if(loopTxt.length===0){
          loopTxt = loopTxt.concat(weeks[index]);
        }else{
          loopTxt = loopTxt.concat(' ').concat(weeks[index]);
        }
        
      }
    }
  }
  return loopTxt;
}

/**
 * 温度转换
 * @param scale 保留小数位
 * @param temp 温度值
 * @param isC 温度单位
 * @returns 返回值
 */
export function tempChangeByTempUtil(scale:number,temp:number,isC:boolean){
  var value = '--'
  if(temp!==-1000){
    if(isC){
      value = utils.scaleNumber(scale,temp);
    }else{
      var tempValue = Math.floor(320+1.8*temp);
      value = utils.scaleNumber(scale,tempValue);
    }
  }   
  return value;
}

/**
 * 获取数据端点数据保存日期（开始日期 - 截止日期）
 * @param duration 数据保存时长（天）
 * @param dateType 数据类型 1（天）、2（小时）、4（月）、16（15 分钟）
 */
export function getDpDataPeriod(duration:number,dateType?:number){
  var start =  null;
  var end = null;
  var day = new Date();
  if(dateType!==undefined){
    switch(dateType){
      case 1:
      case 2:  
        end = utils.dateFormat('yyyyMMdd',day);
        var newDay = new Date(day.getFullYear(),day.getMonth(),day.getDate()-duration);
        start = utils.dateFormat('yyyyMMdd',newDay);
        break;
      case 4:
        end = utils.dateFormat('yyyyMM',day);
        var newDay = new Date(day.getFullYear(),day.getMonth(),day.getDate()-duration);
        start = utils.dateFormat('yyyyMM',newDay);
        break;
        default:
          start = readCurDate0();
          end = start;
          break;    
    }
  }else{
    end = utils.dateFormat('yyyyMMdd',day);
    var newDay = new Date(day.getFullYear(),day.getMonth(),day.getDate()-duration);
    start = utils.dateFormat('yyyyMMdd',newDay);
  }
  return {startDate:start,endDate:end};
}

/**
 * 功能点数据统计时间段
 */
export interface dpDataPeriod{
  /**
   * 功能点
   */
  dataPoint: string;
  dataType: number;
  /**
   * 开始时间
   */
  sDate: string;
  /**
   * 结束时间
   */
  eDate: string;
}

export function showFailedDialog(){
  showToast({title:Strings.getLang('des_fail'),icon:'none',duration:3000,mask:true});
}

export enum TempUnit{
  C = 'c',
  F = 'f',
}
