/**
 * PlayNetKit
 *
 * @version 1.1.3
 */
declare namespace ty.playnet {
  /**
   * 判断是否有这个权限
   *WIFI or BLE
   */
  export function hasPermission(params: {
    /**
     * "WIFI" or "BLE"
     * 权限
     */
    permission: string
    complete?: () => void
    success?: (params: boolean) => void
    fail?: (params: {
      errorMsg: string
      errorCode: string | number
      innerError: {
        errorCode: string | number
        errorMsg: string
      }
    }) => void
  }): void

  /**
   * 请求获取这个权限
   *WIFI or BLE
   */
  export function requestPermission(params: {
    /**
     * "WIFI" or "BLE"
     * 权限
     */
    permission: string
    complete?: () => void
    success?: (params: null) => void
    fail?: (params: {
      errorMsg: string
      errorCode: string | number
      innerError: {
        errorCode: string | number
        errorMsg: string
      }
    }) => void
  }): void

  /**
   * 指定时间内扫描已配网的设备，扫描结果通过【onBLEScanDevice】事件获取
   */
  export function startBLEScanDevice(params: {
    /** 扫描超时时间 */
    timeout: number
    /**
     * 扫描类型
     * SINGLE -> "SINGLE"
     * SINGLE_QR -> "SINGLE_QR"
     * MESH -> "MESH"
     * MESH -> "MESH"
     * SIG_MESH -> "SIG_MESH"
     * NORMAL -> "NORMAL" 默认
     * Thing_BEACON -> "Thing_BEACON"
     * Multi_Mode 双模
     */
    scanType: string
    complete?: () => void
    success?: (params: null) => void
    fail?: (params: {
      errorMsg: string
      errorCode: string | number
      innerError: {
        errorCode: string | number
        errorMsg: string
      }
    }) => void
  }): void

  /**
   * 停止蓝牙扫描
   */
  export function stopBLEScan(params?: {
    complete?: () => void
    success?: (params: null) => void
    fail?: (params: {
      errorMsg: string
      errorCode: string | number
      innerError: {
        errorCode: string | number
        errorMsg: string
      }
    }) => void
  }): void

  /**
   * 蓝牙连接 / AP监听广播包后 并查询状态 然后再开始查询wifi列表
   */
  export function queryDeviceConfigState(params: {
    /** homeid */
    homeId: number
    /** 超时时间 */
    timeout: number
    /**
     * 配网类型，后续新流程添加在这里
     * AP -> "AP"
     * WIFI_BLE -> "WIFI_BLE"
     */
    pairType: string
    /** 蓝牙扫描出来的广播包，目前只有wifi双模需要填写 */
    bleWifiPairParams: ScanDevicePacket
    complete?: () => void
    success?: (params: WiFiInfo[]) => void
    fail?: (params: {
      errorMsg: string
      errorCode: string | number
      innerError: {
        errorCode: string | number
        errorMsg: string
      }
    }) => void
  }): void

  /**
   * 开始配网
   */
  export function startActivator(params: {
    /**
     * 配网类型，后续新流程添加在这里
     * AP -> "AP"
     * WIFI_BLE -> "WIFI_BLE"
     */
    pairType: string
    /** AP 模式下AP配网参数 */
    apActivatorParams: ApActivatorParam
    /** WIFI双模 模式下配网参数 */
    bleWifiActivatorParams: BleWifiActivatorParam
    complete?: () => void
    success?: (params: {
      /** 设备id */
      devId: string
      /** 设备名称 */
      name: string
      /** 设备房间id */
      roomId: string
      /** 设备图标url */
      iconUrl: string
    }) => void
    fail?: (params: {
      errorMsg: string
      errorCode: string | number
      innerError: {
        errorCode: string | number
        errorMsg: string
      }
    }) => void
  }): void

  /**
   * 停止配网
   */
  export function stopActivator(params: {
    /** uuid 根据uuid来匹配找到对应的蓝牙配网设备 */
    uuid: string
    /**
     * 配网类型，后续新流程添加在这里
     * AP -> "AP"
     * WIFI_BLE -> "WIFI_BLE", 蓝牙配网需要填uuid
     */
    pairType: string
    complete?: () => void
    success?: (params: null) => void
    fail?: (params: {
      errorMsg: string
      errorCode: string | number
      innerError: {
        errorCode: string | number
        errorMsg: string
      }
    }) => void
  }): void

  /**
   * 自动连接wifi
   */
  export function autoConnectToAp(params: {
    /** ssid */
    ssid: string
    /** pwd */
    pwd: string
    complete?: () => void
    success?: (params: null) => void
    fail?: (params: {
      errorMsg: string
      errorCode: string | number
      innerError: {
        errorCode: string | number
        errorMsg: string
      }
    }) => void
  }): void

  /**
   * 获取配网token
   */
  export function getPairConfigToken(params: {
    /** 家庭id */
    gid: number
    complete?: () => void
    success?: (params: string) => void
    fail?: (params: {
      errorMsg: string
      errorCode: string | number
      innerError: {
        errorCode: string | number
        errorMsg: string
      }
    }) => void
  }): void

  /**
   * 重置设备
   */
  export function resetDevice(params: {
    /** uuid 根据uuid来匹配找到对应的蓝牙配网设备 */
    uuid: string
    /**
     * 配网类型，后续新流程添加在这里
     * AP -> "AP"
     * WIFI_BLE -> "WIFI_BLE", 蓝牙配网需要填uuid
     */
    pairType: string
    complete?: () => void
    success?: (params: boolean) => void
    fail?: (params: {
      errorMsg: string
      errorCode: string | number
      innerError: {
        errorCode: string | number
        errorMsg: string
      }
    }) => void
  }): void

  /**
   * 获取sl等级配置
   */
  export function getDeviceSecurityConfigs(params?: {
    complete?: () => void
    success?: (params: string) => void
    fail?: (params: {
      errorMsg: string
      errorCode: string | number
      innerError: {
        errorCode: string | number
        errorMsg: string
      }
    }) => void
  }): void

  /**
   * 在自动连接热点场景下，是否是系统控制弹窗的
   */
  export function isSystemPopupInAutoConnectAp(params?: {
    complete?: () => void
    success?: (params: boolean) => void
    fail?: (params: {
      errorMsg: string
      errorCode: string | number
      innerError: {
        errorCode: string | number
        errorMsg: string
      }
    }) => void
  }): void

  /**
   * 是否仅有蓝牙权限
   */
  export function hasBlePermission(params?: {
    complete?: () => void
    success?: (params: boolean) => void
    fail?: (params: {
      errorMsg: string
      errorCode: string | number
      innerError: {
        errorCode: string | number
        errorMsg: string
      }
    }) => void
  }): void

  /**
   * 是否有本地网络权限
   */
  export function hasLocalNetworkPermission(params?: {
    complete?: () => void
    success?: (params: boolean) => void
    fail?: (params: {
      errorMsg: string
      errorCode: string | number
      innerError: {
        errorCode: string | number
        errorMsg: string
      }
    }) => void
  }): void

  /**
   * 扫描到设备后进行通知
   */
  export function onBLEScanDevice(
    listener: (params: ScanDevicePacket) => void
  ): void

  /**
   * 取消监听：扫描到设备后进行通知
   */
  export function offBLEScanDevice(
    listener: (params: ScanDevicePacket) => void
  ): void

  /**
   * wifi状态发生变化
   */
  export function onWifiStateChange(listener: (params: Privacy) => void): void

  /**
   * 取消监听：wifi状态发生变化
   */
  export function offWifiStateChange(listener: (params: Privacy) => void): void

  /**
   * 蓝牙状态发生变化
   */
  export function onBLEStateChange(listener: (params: Privacy) => void): void

  /**
   * 取消监听：蓝牙状态发生变化
   */
  export function offBLEStateChange(listener: (params: Privacy) => void): void

  /**
   * 蓝牙权限发生变化
   */
  export function onBlePermissionChange(
    listener: (params: Privacy) => void
  ): void

  /**
   * 取消监听：蓝牙权限发生变化
   */
  export function offBlePermissionChange(
    listener: (params: Privacy) => void
  ): void

  /**
   * 本地网络权限发生变化
   */
  export function onlocalNetWorkPermissionChange(
    listener: (params: Privacy) => void
  ): void

  /**
   * 取消监听：本地网络权限发生变化
   */
  export function offlocalNetWorkPermissionChange(
    listener: (params: Privacy) => void
  ): void

  export type ScanDevicePacket = {
    /** id */
    id: string
    /** name */
    name: string
    /** providerName */
    providerName: string
    /** data */
    data: string
    /** configType */
    configType: string
    /** productId */
    productId: string
    /** uuid */
    uuid: string
    /** mac */
    mac: string
    /** address */
    address: string
    /** deviceType */
    deviceType: number
    /** isbind */
    isbind: boolean
    /** flag */
    flag: number
    /** isShare */
    isShare: boolean
    /** rssi */
    rssi: number
  }

  export type WiFiInfo = {
    /** ssid */
    ssid: string
    /** 强度 */
    rssi: number
    /** sec */
    sec: number
  }

  export type ApActivatorParam = {
    /** ssid */
    ssid: string
    /** pwd */
    pwd: string
    /** token */
    token: string
    /** 配网超时时间 */
    timeout: number
    /** 是否为密码错误恢复配网 */
    isRecovery: boolean
    /**
     * securityConfig
     * use getDeviceSecurityConfigs() method to get
     */
    securityConfig: string
  }

  export type BleWifiActivatorParam = {
    /** uuid */
    uuid: string
    /** ssid */
    ssid: string
    /** pwd */
    pwd: string
    /** token */
    token: string
    /** timeout */
    timeout: number
    /** 是否为密码错误恢复配网 */
    isRecovery: boolean
    /**
     * the phase 1 timeout value, in milliseconds. Default 60000
     * Note
     * <p>
     * For devices with WiFi and Bluetooth capabilities, use WiFi to activate in the first stage, if it fails, use Bluetooth to activate.
     */
    phase1Timeout: number
  }

  export type Privacy = {
    /** enable */
    enable: boolean
  }
}
